// rollup.config.js

import typescript from '@rollup/plugin-typescript';
import resolve from '@rollup/plugin-node-resolve';
import commonjs from '@rollup/plugin-commonjs';
import copy from 'rollup-plugin-copy';
import { dts } from 'rollup-plugin-dts';

/**
 * @type {import('rollup').RollupOptions}
 */
const config1 = {
  input: 'src/index.ts', // TypeScript 入口文件
  output: {
    file: 'dist/html.js', // 输出文件
    format: 'es', // 输出格式设置为 ES 模块
  },
  plugins: [
    resolve({
      browser: true, // 若为浏览器环境，设为 true；若为 Node.js 环境，设为 false
      preferBuiltins: false, // 优先使用内置模块
    }), // 使用 @rollup/plugin-node-resolve 解析 node_modules 中的模块
    // commonjs(), //

    typescript({
      allowImportingTsExtensions: true,
      noEmit: true,
      declaration: false,
    }), // 使用 @rollup/plugin-typescript 处理 TypeScript 文件
  ],
  include: ['node_modules/**'],
  external: [],
};
const config1Dts = {
  input: 'src/index.ts', // TypeScript 入口文件
  output: {
    file: 'dist/html.d.ts', // 输出文件
    format: 'es', // 输出格式设置为 ES 模块
  },
  plugins: [
    dts(), // 生成 .d.ts 类型声明文件
  ],
  external: [],
  include: ['node_modules/**'],
};

export default [config1, config1Dts];
